clc; tic

%% Inputs from user
[~,S,~,Opt_n,r,ConfLvl]=User_GeneralInputs(); % to call parameters for running the GMA.
% See the function (User_GeneralInputs) for more information.
Beta_int=User_OptInitiation(); % to call start points for the optimization search

%% Estimate weighting matrix (W) and run optimization

for z=1:Opt_n
    if z==1
        % First round of optimization based on initial W
        [EmpSign,~]=GMA_Signatures(Beta_int,1,r); % to call empirical signatures
        W=diag(1./(EmpSign.^2)); % the diagonal of this W is the inverse of
        % empirical signatures.
        [Beta,ObjFnVal]=GMA_Optimization(Beta_int,W); % to run optimization solver
        % optimization search starts from Beta_int and its output, estimated
        % parameters are Beta.
    else
        % Additional rounds of optimization based on updated W
        [W,SS]=GMA_W_star(Beta,r); % here W is the inverse of covariance matrix
        % of simulated signatures, given the estimated Beta.
        [Beta,ObjFnVal]=GMA_Optimization(Beta,W); % to run optimization solver
        % optimization search starts from Beta
    end
    % capture estimated W, Beta, and ObjFnVal in each iteration (not needed
    % in GMA, captured only for additional analysis if needed be).
    W_all(:,:,z)=W; Beta_all(z,:)=Beta; ObjFnVal_all(z,:)=ObjFnVal;
end

%% Estimate confidence intervals
Q = GMA_Var_EstimatedVar(Beta, W, SS); % to calculate the covariance matrix of
% the estimated parameters (Beta). 
Std_Beta=sqrt(diag(Q)); % The diagonal of Q includes variances of the estimated Beta
[ConfDown, ConfUp]=GMA_Var_ConfInt(Beta, ConfLvl, Std_Beta); % confidence intervals of
% the estimated Beta

% Wrap up a few additional results (for further analysis):
SimSign_S=GMA_Signatures(Beta,S,r);
SimSign=sum(SimSign_S, 2)/S; % simulated signatures based on estimated parameters
All_Sign=[EmpSign,SimSign]; % to put empirical and simulated signatures in two
% columns next to each other

%% Save MATLAB workspace
save(['Final_Results_Run_' num2str(r) '.mat']); % Use your preferred name
% for this workspace.
display('Done! All results are saved.');
toc; % tic and toc show the total calculation time