% Empirical and simulated signatures for prior model 2

function [EmpSign,SimSign]=User_model_2(Beta,s,r)

%% Empirical signatures
% this information should be captured from the reported results for this model

EmpSign=[1.064;	0.783;	1.422;	1.449];
% in this example, the first three numbers are coefficients of the
% regression and the last number is the error variance of the regression
	
n=100; % sample size for this study

%% Simulated signatures
% 1) Generate simulated explanatory variables (X)
SIGMA=User_SIGMA(); % Covariance matrix of X
X=User_DataGeneration(SIGMA,n,s,r); % X is generated in User_DataGeneration function

% 2) Generate simulated Y using the meta model, simulated X, and Beta
Y=User_Meta_model(Beta,X,s,r);

% 3) Sample from X (based on the data used in this model)
SX = [ones(n,1) X(:,1) X(:,3)]; % In this example, X has three variables (X1-X3) but
% this study only uses two of the variables

% 4) Calculate the signatures
% Empirical signatures in this studies were results of regression modeling,
% therefore regression is run on Y and SX to estimate simulated signatures.
[coeff,~,~,~,StatResults] = regress(Y,SX);
ErrVar=StatResults(4);

SimSign=[coeff; ErrVar]; % put all signatures in a vector of simulated signatures
% >> IMPORTANT: SimSign must be sorted based on their empirical counterparts (EmpSign).

end